@@ -20,7 +20,7 @@ class ComboBox : public QComboBox {
     Q_OBJECT
 
    public:
-    explicit ComboBox(QWidget *parent = Q_NULLPTR);
+    explicit ComboBox(QWidget *parent = nullptr);
 
    protected:
    private slots:
